@@ -18,8 +18,7 @@
 get_jagscode = function(prior, ST, formula_str, arma_order, family, sample) {
   # Begin building JAGS model. `mm` is short for "mcp model".
   # Add fixed variables.
-  mm = paste0("
-model {")
+  mm = paste0("model {")
 
   ####################################
   # DIRICHLET PRIOR ON CHANGE POINTS #
@@ -116,7 +115,7 @@ model {")
   y_code = "y_[i_]"
   if (has_ar)
     y_code = paste0(y_code, " + resid_arma_[i_]")
-  y_code = paste0(family$linkinv_jags, "(", y_code, ")")
+  y_code = paste0(family$linkinv_str, "(", y_code, ")")
 
   # Prepare variance code
   has_weights = !all(is.na(ST$weights))
@@ -146,9 +145,9 @@ model {")
   # Compute residuals for AR
   if (has_ar) {
     if (family$family == "binomial") {
-      mm = paste0(mm, "\n    resid_abs_[i_] = ", family$link_jags, "(", ST$y[1], "[i_] / ", ST$trials[1], "[i_]) - y_[i_]  # Residuals represented by sigma_ after ARMA")
+      mm = paste0(mm, "\n    resid_abs_[i_] = ", family$linkfun_str, "(", ST$y[1], "[i_] / ", ST$trials[1], "[i_]) - y_[i_]  # Residuals represented by sigma_ after ARMA")
     } else {
-      mm = paste0(mm, "\n    resid_abs_[i_] = ", family$link_jags, "(", ST$y[1], "[i_])  - y_[i_]  # Residuals represented by sigma_ after ARMA")
+      mm = paste0(mm, "\n    resid_abs_[i_] = ", family$linkfun_str, "(", ST$y[1], "[i_])  - y_[i_]  # Residuals represented by sigma_ after ARMA")
     }
   }
 
@@ -177,7 +176,7 @@ model {")
 #' @keywords internal
 #' @inheritParams mcp
 #' @param i The index in `prior` to get code for
-#' @param varying_group String or NULL (default). Null indicates a population-
+#' @param varying_group String or NULL. Null indicates a population-
 #'   level prior. String indicates a varying-effects prior (one for each group
 #'   level).
 #' @return A string
