@@ -29,11 +29,14 @@ get_arma_order = function(pars_arma) {
 # Ask reminder questions for CRAN export
 release_questions = function() {
   c(
-    "Have you run the test of fits? options(test_mcp_fits = TRUE)",
-    "Have you built the README plots and checked them? source('vignettes/figures/make_README_plots.R')",
-    "Have you re-built the site using pkgdown::build_site() AFTER deleting caches of articles?",
-    "Have you checked all articles and plots after re-building the site?",
-    "Have you run the script to insert the correct logo.png in the HTML meta?"
+    "TEST: Have you run the extensive tests? options(test_mcp_allmodels = TRUE)",
+    "TEST: Have you run the test of fits? options(test_mcp_fits = TRUE)",
+    "TEST: Have you run `revdepcheck::revdep_check()`?",
+
+    "DOC: Have you built the README plots and checked them? source('vignettes/figures/make_README_plots.R')",
+    "DOC: Have you re-built the site using pkgdown::build_site() AFTER deleting caches of articles in 'vignettes/*_cache/'?",
+    "DOC: Have you checked all articles and plots after re-building the site?",
+    "DOC: Have you run the script to insert the correct logo.png in the HTML meta?"
   )
 }
 
